package com.ruoyi.web.work.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.work.domain.Banner;
import com.ruoyi.web.work.domain.News;
import com.ruoyi.web.work.domain.Notice;
import com.ruoyi.web.work.domain.Position;
import com.ruoyi.web.work.service.IBannerService;
import com.ruoyi.web.work.service.INewsService;
import com.ruoyi.web.work.service.INoticeService;
import com.ruoyi.web.work.service.IPositionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * 轮播图
 *
 * @author lsw
 * @date 2024-04-15
 */
@RestController
@RequestMapping("/work/banner")
public class BannerController extends BaseController {
    @Autowired
    private IBannerService bannerService;

    @Autowired
    private INewsService newsService;

    @Autowired
    private INoticeService noticeService;

    @Autowired
    private IPositionService positionService;


    @PreAuthorize("@ss.hasPermi('work:banner:list')")
    @GetMapping("/list")
    public TableDataInfo list(Banner banner) {
        startPage();
        List<Banner> list = bannerService.selectList(banner);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('work:banner:edit')")
    @GetMapping("/selectUrl")
    public TableDataInfo selectUrl(String type, String title) {
        if (type.equals("新闻资讯")) {
            startPage();
            List<News> list = newsService.selectList(new News().setTitle(title).setState(0));
            return getDataTable(list);
        }
        if (type.equals("通知公告")) {
            startPage();
            List<Notice> list = noticeService.selectList(new Notice().setTitle(title).setState(0));
            return getDataTable(list);
        }
        if (type.equals("工作职位")) {
            startPage();
            List<Position> list = positionService.selectList(new Position().setTitle(title).setAudit(1).setState(0));
            return getDataTable(list);
        }
        return getDataTable(new ArrayList());
    }

    @PreAuthorize("@ss.hasPermi('work:banner:query')")
    @GetMapping(value = "/detail/{id}")
    public AjaxResult detail(@PathVariable("id") Long id) {
        return AjaxResult.success(bannerService.getById(id));
    }

    @PreAuthorize("@ss.hasPermi('work:banner:add')")
    @Log(title = "轮播图", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    public AjaxResult add(@RequestBody Banner banner) {
        return toAjax(bannerService.save(banner));
    }

    @PreAuthorize("@ss.hasPermi('work:banner:edit')")
    @Log(title = "轮播图", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody Banner banner) {
        return toAjax(bannerService.updateById(banner));
    }

    @PreAuthorize("@ss.hasPermi('work:banner:remove')")
    @Log(title = "轮播图", businessType = BusinessType.DELETE)
    @GetMapping("/remove/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bannerService.removeByIds(Arrays.asList(ids)));
    }
}
